@@ -4,6 +4,8 @@
 #include <glib.h>
 #include <glib-object.h>
 
+/* type macros */
+
 #define GTKDOC_TYPE_OBJECT            (gtkdoc_object_get_type ())
 #define GTKDOC_OBJECT(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKDOC_TYPE_OBJECT, GtkdocObject))
 #define GTKDOC_OBJECT_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GTKDOCTYPE_OBJECT, GtkdocObjectClass))
@@ -11,17 +13,19 @@
 #define GTKDOC_IS_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKDOC_TYPE_OBJECT))
 #define GTKDOC_OBJECT_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKDOC_TYPE_OBJECT, GtkdocObjectClass))
 
-/* type macros */
+/* type structs */
 
 typedef struct _GtkdocObject GtkdocObject;
 typedef struct _GtkdocObjectClass GtkdocObjectClass;
 
 /* in gtkdoc-scan::ScanHeader() we currently skip the enums, but output a decl
 * to -decl.txt and -decl-list.txt for the struct
-* If the symbol has no docs, we get a warning in -unused.txt
-*/
+* If the symbol has no docs, we get a warning in -unused.txt for the struct, but
+* not the enum
+*
 typedef struct GtkdocHelperStruct GtkdocHelperStruct;
 typedef enum GtkdocHelperEnum GtkdocHelperEnum;
+*/
 
 /**
  * GtkdocObject:
@@ -65,6 +69,7 @@ GtkdocObject *gtkdoc_object_new(void);
 void gtkdoc_object_set_otest (GObject *self, const gchar *value);
 #endif
 void gtkdoc_object_frobnicate (GObject *self, gint n);
+gboolean gtkdoc_object_fooify (GObject *self, ...);
 
 /**
  * GTKDOC_OBJECT_MACRO_DUMMY:
